use serde::Serialize;

use crate::cards::hand::Hand;

#[derive(Serialize, Clone)]
pub struct PlayingHand {
    pub(super) hand: Hand,
    pub(super) state: HandState,
}

impl PlayingHand {
    pub(super) fn new() -> Self {
        PlayingHand {
            hand: Hand::new(),
            state: HandState::Playing,
        }
    }

    pub fn get_hand(&self) -> &Hand {
        &self.hand
    }

    pub fn get_state(&self) -> &HandState {
        &self.state
    }
}

#[derive(Clone, Copy, Debug, PartialEq, Serialize)]
pub enum HandState {
    Playing,
    Standing,
    DoubleDown,
    Busted,
    Blackjack,
    Maxed, // Reached 21
}
